@@ -700,7 +700,7 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
 
 
 async def bAsyncDownload(url, file):
-    result, _response = await bAsyncHttpGet(self.url)
+    result, _response = await bAsyncHttpGet(url)
     await bAsyncWriteBinFile(file, result)
 
 
